@@ -177,6 +177,7 @@ class ChargingSensor(VehicleDevice):
         self.__charge_current_request = None
         self.__charger_actual_current = None
         self.__charger_voltage = None
+        self.__charger_soc_limit = None
 
     async def async_update(self, wake_if_asleep=False, force=False) -> None:
         """Update the battery state."""
@@ -207,6 +208,8 @@ class ChargingSensor(VehicleDevice):
             self.__charge_current_request = data["charge_current_request"]
             self.__charger_actual_current = data["charger_actual_current"]
             self.__charger_voltage = data["charger_voltage"]
+            self.__charge_limit_soc = data["charge_limit_soc"]
+            self.attrs["charge_limit_soc"] = self.charge_soc_limit
             if self.measurement != "mi/hr":
                 self.__added_range = round(self.__added_range / 0.621371, 2)
                 self.__charging_rate = round(self.__charging_rate / 0.621371, 2)
@@ -251,6 +254,11 @@ class ChargingSensor(VehicleDevice):
         """Return the energy added."""
         return self.__charge_energy_added
 
+    @property
+    def charge_soc_limit(self) -> int:
+        """Return the state of charge limit."""
+        return self.__charge_limit_soc
+
     @property
     def device_class(self) -> Text:
         """Return the HA device class."""
